@@ -1,9 +1,9 @@
 # Copyright (C) 2012 Xue Can <xuecan@gmail.com> and contributors.
 # Licensed under the MIT license: http://www.opensource.org/licenses/mit-license
 
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 
-from stores import Redis, Store, SerializationStore,\
+from stores import StrictRedis, Redis, Store, SerializationStore,\
                    PickleStore, JsonStore, MongoExtendedJsonStore
 from caches import CacheManager
 from locks import Lock, LockManager
